Learn R Programming

genphen (version 1.0.0)

genotype.saap.msa: SAAP genotype dataset (msa)

Description

The genotype.saap.msa data is a multiple sequence alignment in Biostrings AAMultipleAlignment format. It contains 120 protein sequences, each with 154 sites (SAAPs). The data is used in combination with the phenotype.aa data to quantify the association between each amino acid substitution pair and the phenotype vector.

Usage

data("genotype.saap.msa")

Arguments

Value

AAMultipleAlignment object with 120 sequences each made of 154 amino acid sites (SNPs), some of which qualify as single amino acid polymorphisms.

Format

AAMultipleAlignment object with 120 sequences each made of 154 amino acid sites (SNPs), some of which qualify as single amino acid polymorphisms.

http://www.ncbi.nlm.nih.gov/genbank/

Examples

Run this code
data("genotype.saap.msa")

Run the code above in your browser using DataLab