Learn R Programming

genphen (version 1.0.0)

genotype.snp: SNP genotype dataset

Description

The genotype.snp data is a character matrix with dimensions 51x100. It contains 100 SNPs across 51 mouse strains, taken from the publicly available Mouse Hapmap data. We used it in combination with the phenotype.snp data to compute the association between each SNP and the phenotype data.

Usage

data(genotype.snp)

Arguments

Value

Matrix with 51 rows and 100 columns, whereby each column is a SNP, and the elements represent an alleles (nucleotides).

Format

A matrix with 51 observations (laboratory mouse strains) and 100 variables (SNPs).

http://mouse.cs.ucla.edu/mousehapmap/emma.html

Examples

Run this code
data(genotype.snp)

Run the code above in your browser using DataLab